# app/core/logger.py
import logging
import logging.config

def configure_logging():
    """Configure basic logging."""
    logging_config = {
        "version": 1,
        "disable_existing_loggers": False,
        "formatters": {
            "simple": {
                "format": "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
            }
        },
        "handlers": {
            "console": {
                "class": "logging.StreamHandler",
                "level": "DEBUG",
                "formatter": "simple",
                "stream": "ext://sys.stdout",
            },
            "file": {
                "class": "logging.FileHandler",
                "level": "INFO",
                "formatter": "simple",
                "filename": "household_api.log",
                "mode": "a",  # Append to the log file
            },
        },
        "loggers": {
            "api": {
                "handlers": ["console", "file"],
                "level": "DEBUG",
                "propagate": True,
            },
            "services": {
                "handlers": ["console", "file"],
                "level": "INFO",
                "propagate": True,
            },
            "db": {
                "handlers": ["console", "file"],
                "level": "WARN",
                "propagate": True,
            },
            "shopping_lists": {
                "handlers": ["console", "file"],
                "level": "INFO",
                "propagate": True,
            },
        },
        "root": {
            "level": "WARNING",
            "handlers": ["console", "file"],
        },
    }
    logging.config.dictConfig(logging_config)

# Initialize logging configuration
configure_logging()

# Get logger instance for use in other modules
logger = logging.getLogger("api")
shopping_lists_logger = logging.getLogger("shopping_lists")
