# app/models/house.py
import uuid
from datetime import datetime

from sqlalchemy import Column, DateTime, ForeignKey, String, Text
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy.orm import relationship

from app.db.base import Base


class House(Base):
    __tablename__ = "houses"

    id = Column(UUID(as_uuid=True), primary_key=True, default=uuid.uuid4)
    name = Column(String(255), nullable=False)
    description = Column(Text)
    created_at = Column(DateTime, default=datetime.utcnow)
    updated_at = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow)

    # Relationships
    members = relationship(
        "HouseMember",
        back_populates="house",
        cascade="all, delete-orphan"
    )
    shopping_lists = relationship(
        "ShoppingList",
        back_populates="house",
        cascade="all, delete-orphan"
    )
    chores = relationship(
        "Chore",
        back_populates="house",
        cascade="all, delete-orphan"
    )
    invites = relationship(
        "HouseInvite",
        back_populates="house",
        cascade="all, delete-orphan"
    )


class HouseMember(Base):
    __tablename__ = "house_members"

    id = Column(UUID(as_uuid=True), primary_key=True, default=uuid.uuid4)
    house_id = Column(UUID(as_uuid=True), ForeignKey("houses.id"), nullable=False)
    user_id = Column(UUID(as_uuid=True), ForeignKey("users.id"), nullable=False)
    role = Column(String(50), default="member")
    created_at = Column(DateTime, default=datetime.utcnow)

    # Relationships
    house = relationship("House", back_populates="members")
    user = relationship("User")
