# app/models/invite.py
import uuid
from datetime import datetime

from sqlalchemy import Column, DateTime, ForeignKey, String
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy.orm import relationship

from app.db.base import Base


class HouseInvite(Base):
    __tablename__ = "house_invites"

    id = Column(UUID(as_uuid=True), primary_key=True, default=uuid.uuid4)
    code = Column(String(255), unique=True, nullable=False, index=True)
    house_id = Column(UUID(as_uuid=True), ForeignKey("houses.id"), nullable=False)
    inviter_id = Column(UUID(as_uuid=True), ForeignKey("users.id"), nullable=False)
    created_at = Column(DateTime, default=datetime.utcnow)
    expires_at = Column(DateTime, nullable=False)

    # Relationships
    # (The host-side as a “child” of House; see also the update below in app/models/house.py)
    house = relationship("House", back_populates="invites")
    inviter = relationship("User")
