# app/schemas/chore.py
from datetime import datetime
from typing import Optional
from uuid import UUID

from pydantic import BaseModel


class ChoreBase(BaseModel):
    title: str
    description: Optional[str] = None
    due_date: Optional[datetime] = None


class ChoreCreate(ChoreBase):
    assigned_to: Optional[UUID] = None


class ChoreUpdate(ChoreBase):
    title: Optional[str] = None
    assigned_to: Optional[UUID] = None
    is_completed: Optional[bool] = None


class ChoreAssign(BaseModel):
    assigned_to: UUID


class ChoreComplete(BaseModel):
    is_completed: bool


class Chore(ChoreBase):
    id: UUID
    house_id: UUID
    assigned_to: Optional[UUID] = None
    is_completed: bool
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True
