# app/schemas/expense.py
from datetime import datetime
from decimal import Decimal
from typing import List, Optional
from uuid import UUID

from pydantic import BaseModel


class ExpenseSplitBase(BaseModel):
    user_id: UUID
    amount: Decimal


class ExpenseSplitCreate(ExpenseSplitBase):
    pass


class ExpenseSplit(ExpenseSplitBase):
    id: UUID
    expense_id: UUID
    created_at: datetime

    class Config:
        from_attributes = True


class ExpenseBase(BaseModel):
    amount: Decimal
    description: Optional[str] = None
    date: Optional[datetime] = None


class ExpenseCreate(ExpenseBase):
    payer_id: UUID
    splits: List[ExpenseSplitCreate]


class ExpenseUpdate(ExpenseBase):
    payer_id: Optional[UUID] = None
    splits: Optional[List[ExpenseSplitCreate]] = None


class Expense(ExpenseBase):
    id: UUID
    list_id: UUID
    payer_id: UUID
    created_at: datetime
    splits: List[ExpenseSplit] = []

    class Config:
        from_attributes = True


class ExpenseSummary(BaseModel):
    total_amount: Decimal
    user_balances: dict[UUID, Decimal]
