# app/schemas/house.py
from datetime import datetime
from typing import List, Optional
from uuid import UUID

from pydantic import BaseModel


class HouseBase(BaseModel):
    name: str
    description: Optional[str] = None


class HouseCreate(HouseBase):
    pass


class HouseUpdate(HouseBase):
    name: Optional[str] = None


class HouseMemberBase(BaseModel):
    role: str = "member"


class HouseMemberCreate(HouseMemberBase):
    user_id: UUID


class HouseMemberUpdate(HouseMemberBase):
    pass


class HouseMember(HouseMemberBase):
    id: UUID
    house_id: UUID
    user_id: UUID
    created_at: datetime

    class Config:
        from_attributes = True


class HouseMemberResponse(BaseModel):
    id: UUID
    house_id: UUID
    user_id: UUID
    role: str
    created_at: datetime

    class Config:
        orm_mode = True


class House(HouseBase):
    id: UUID
    created_at: datetime
    updated_at: datetime
    members: List[HouseMember] = []

    class Config:
        from_attributes = True
