# app/schemas/shopping_list.py
from datetime import datetime
from decimal import Decimal
from typing import List, Optional
from uuid import UUID

from pydantic import BaseModel, Field


class ListItemBase(BaseModel):
    name: str
    quantity: Optional[Decimal] = Field(1, ge=0)
    unit: Optional[str] = None
    price: Optional[Decimal] = None
    position: Optional[int] = None


class ListItemCreate(ListItemBase):
    pass


class ListItemUpdate(ListItemBase):
    name: Optional[str] = None
    is_completed: Optional[bool] = None


class ListItem(ListItemBase):
    id: UUID
    list_id: UUID
    is_completed: bool
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True


class ShoppingListBase(BaseModel):
    title: str
    description: Optional[str] = None


class ShoppingListCreate(ShoppingListBase):
    pass


class ShoppingListUpdate(ShoppingListBase):
    title: Optional[str] = None
    is_archived: Optional[bool] = None


class ShoppingList(ShoppingListBase):
    id: UUID
    house_id: UUID
    is_archived: bool
    created_at: datetime
    updated_at: datetime
    items: List[ListItem] = []

    class Config:
        from_attributes = True


class ItemReorder(BaseModel):
    item_id: UUID
    new_position: int
