// src/lib/stores/toast.ts
import { writable } from 'svelte/store';

type ToastType = 'success' | 'error' | 'info' | 'warning';

interface ToastState {
    visible: boolean;
    message: string;
    type: ToastType;
}

function createToastStore() {
    const { subscribe, set, update } = writable<ToastState>({
        visible: false,
        message: '',
        type: 'info'
    });

    let timeout: NodeJS.Timeout;

    function show(message: string, type: ToastType = 'info', duration: number = 3000) {
        // Clear any existing timeout
        if (timeout) clearTimeout(timeout);

        // Show the toast
        set({ visible: true, message, type });

        // Hide after duration
        timeout = setTimeout(() => {
            update(state => ({ ...state, visible: false }));
        }, duration);
    }

    function hide() {
        if (timeout) clearTimeout(timeout);
        update(state => ({ ...state, visible: false }));
    }

    return {
        subscribe,
        show,
        hide,
        success: (message: string, duration?: number) => show(message, 'success', duration),
        error: (message: string, duration?: number) => show(message, 'error', duration),
        warning: (message: string, duration?: number) => show(message, 'warning', duration),
        info: (message: string, duration?: number) => show(message, 'info', duration)
    };
}

export const toastStore = createToastStore();
