export interface User {
    id: string;
    email: string;
    full_name?: string;
    created_at: string;
    updated_at: string;
}

export interface House {
    id: string;
    name: string;
    description?: string;
    created_at: string;
    updated_at: string;
    members: HouseMember[];
}

export interface HouseInvite {
    id: string;
    code: string;
    house_id: string;
    inviter_id: string;
    created_at: string;
    expires_at: string;
}

export interface HouseMember {
    id: string;
    house_id: string;
    user_id: string;
    role: string;
    created_at: string;
}

export interface ShoppingList {
    id: string;
    house_id: string;
    title: string;
    description?: string;
    is_archived: boolean;
    created_at: string;
    updated_at: string;
    items: ListItem[];
}

export interface ListItem {
    id: string;
    list_id: string;
    name: string;
    quantity: number;
    unit?: string;
    price?: number;
    is_completed: boolean;
    position: number;
    created_at: string;
    updated_at: string;
}

export interface ExpenseSplit {
    id: string;
    expense_id: string;
    user_id: string;
    amount: number;
    created_at: string;
    user?: User;
}

export interface Expense {
    id: string;
    list_id: string;
    payer_id: string;
    amount: number;
    description?: string;
    date: string;
    created_at: string;
    payer?: User;
    splits: ExpenseSplit[];
}

export interface ExpenseSummary {
    total_amount: number;
    user_balances: Record<string, number>;
}

export interface Chore {
    id: string;
    house_id: string;
    title: string;
    description?: string;
    assigned_to?: string;
    due_date?: string;
    is_completed: boolean;
    created_at: string;
    updated_at: string;
    assignee?: User;
    frequency?: string;
}
